import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

#
# Display hook
# 
# Create TOP pages page
#
# Plugin requirements :
#     post_analysis/top_pages
#
# Conf values needed :
#     max_pages_displayed*
#     create_all_pages_page*
#
# Output files :
#     OUTPUT_ROOT/year/month/top_pages.html
#     OUTPUT_ROOT/year/month/index.html
#
# Statistics creation :
#     None
#
# Statistics update :
#     None
#
# Statistics deletion :
#     None
#

class IWLADisplayTopPages(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopPages, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisTopPages']
        self.max_pages = self.iwla.getConfValue('max_pages_displayed', 0)
        self.create_all_pages = self.iwla.getConfValue('create_all_pages_page', True)

    def hook(self):
        display = self.iwla.getDisplay()
        top_pages = self.iwla.getMonthStats()['top_pages']
        top_pages = sorted(top_pages.items(), key=lambda t: t[1], reverse=True)

        # All in a page
        if self.create_all_pages:
            title = time.strftime('All Pages - %B %Y', self.iwla.getCurTime())
            filename = 'top_pages.html'
            path = self.iwla.getCurDisplayPath(filename)

            page = display.createPage(title, path, self.iwla.getConfValue('css_path', []))
            table = display.createBlock(DisplayHTMLBlockTable, 'All Pages', ['URI', 'Entrance'])
            table.setColsCSSClass(['', 'iwla_hit'])
            total_hits = [0]*2        
            new_list = self.max_pages and top_pages[:self.max_pages] or top_pages
            for (uri, entrance) in new_list:
                table.appendRow([generateHTMLLink(uri), entrance])
                total_hits[1] += entrance
            page.appendBlock(table)

            display.addPage(page)

        title = 'Top Pages'
        if self.create_all_pages:
            link = '<a href=\'%s\'>All Pages</a>' % (filename)
            title = '%s - %s' % (title, link)

        # Top in index
        index = self.iwla.getDisplayIndex()
        
        table = display.createBlock(DisplayHTMLBlockTable, title, ['URI', 'Entrance'])
        table.setColsCSSClass(['', 'iwla_hit'])
        for (uri, entrance) in top_pages[:10]:
            table.appendRow([generateHTMLLink(uri), entrance])
            total_hits[1] -= entrance
        if total_hits[1]:
            total_hits[0] = 'Others'
            table.appendRow(total_hits)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')
        index.appendBlock(table)
